@@ -49,20 +49,83 @@ class CdPipelineHandlers:
                     'error': f'Failed to confirm deletion of CD pipeline {cd_pipeline_id}'
                 }
             else:
-                return {
-                    'success': False,
-                    'error': f'Failed to delete CD pipeline: {response.text}'
-                }
+                try:
+                    error_json = response.json()
+                    errors = error_json.get('errors', [])
+                    user_message = None
+                    if errors:
+                        # Extract userMessage from the first error
+                        user_message = errors[0].get('userMessage') or errors[0].get('internalMessage')
+                    
+                    if user_message:
+                        return {
+                            'success': False,
+                            'error': f'Failed to delete CD pipeline {cd_pipeline_id}: {user_message}'
+                        }
+                    else:
+                        return {
+                            'success': False,
+                            'error': f'Failed to delete CD pipeline: {response.text}'
+                        }
+                except json.JSONDecodeError:
+                    # If response is not valid JSON, return the raw text
+                    return {
+                        'success': False,
+                        'error': f'Failed to delete CD pipeline: {response.text}'
+                    }
         except Exception as e:
             return {
                 'success': False,
                 'error': f'Exception occurred: {str(e)}'
             }
 
+    @staticmethod
+    def get_env_ns_details(base_url, headers, env):
+        import  requests
+        try:
+            url = f"{base_url}/orchestrator/env/autocomplete"
+            params = {
+                "auth": "false",
+                "showDeploymentOptions": "true"
+            }
+            response = requests.get(url, headers=headers, params=params)
+            if response.status_code != 200:
+                return {
+                    "success": False,
+                    "error": "Failed to get the env to namespace details"
+                }
+            result = response.json().get("result", [])
+            for e in result:
+                if e.get("environment_name") == env:
+                    return {
+                        "success": True,
+                        "namespace": e.get("namespace")
+                    }
+            return {
+                "success": False,
+                "error": "Environment not found"
+            }
+
+        except Exception as e:
+            return {
+                "success": False,
+                "error": str(e)
+            }
+
+
 
     @staticmethod
     def update_cd_pipeline(base_url: str, headers: dict, app_id: int, cd_pipeline_id: int, cd_config):
         try:
+            environment_name = cd_config.get("environment_name")
+            get_ns = CdPipelineHandlers.get_env_ns_details(base_url, headers, environment_name)
+            if not get_ns["success"]:
+                return {
+                    "success": False,
+                    "error": "Failed to get the ns details"
+                }
+            namespace = get_ns.get("namespace")
+
             cd_pipeline = CdPipelineHandlers.get_cd_pipeline(base_url, headers, app_id, cd_pipeline_id)
             if not cd_pipeline["success"]:
                 return {
@@ -134,7 +197,7 @@ class CdPipelineHandlers:
             cd.pre_deploy_stage = updated_pre_cd_configs
             cd.post_deploy_stage = updated_post_cd_configs
 
-            patch_cd_result = CdPipelineHandlers.patch_cd_pipeline(base_url, headers, cd)
+            patch_cd_result = CdPipelineHandlers.patch_cd_pipeline(base_url, headers, cd, namespace)
 
             if not patch_cd_result["success"]:
                 print("Failed to patch CD Pipeline")
@@ -156,7 +219,7 @@ class CdPipelineHandlers:
             }
 
     @staticmethod
-    def patch_cd_pipeline(base_url, headers, cd_pipeline: CdPipeline):
+    def patch_cd_pipeline(base_url, headers, cd_pipeline: CdPipeline, namespace: str):
         import requests, json
         try:
 
@@ -176,10 +239,9 @@ class CdPipelineHandlers:
                 "appId": cd_pipeline.app_id,
                 "pipeline": {
                     "name": cd_pipeline.name,
-                    "appWorkflowId": 420,
                     "ciPipelineId": cd_pipeline.ci_pipeline_id,
                     "environmentId": cd_pipeline.environment_id,
-                    "namespace": "devtron-demo",
+                    "namespace": namespace,
                     "id": cd_pipeline.id,
                     "strategies": cd_pipeline.strategies,
                     "parentPipelineType": cd_pipeline.parent_pipeline_type,
