@@ -661,6 +661,32 @@ class DevtronUtils:
                     for plugin in plugin_list:
                         if plugin.get("name") == plugin_name:
                             return {'success': True, 'plugin': plugin}
-            return {}
+                # Plugin not found
+                return {'success': False, 'error': f'Plugin "{plugin_name}" not found in available plugins'}
+            else:
+                return {'success': False, 'error': f'API request failed with status code {status_code}: {data.get("errors", "Unknown error")}'}
         except Exception as e:
-            return {'success': False, 'error': f'Exception occurred: {str(e)}'}
\ No newline at end of file
+            return {'success': False, 'error': f'Exception occurred: {str(e)}'}
+
+
+    @staticmethod
+
+    def get_cd_pipelines(base_url, headers, app_id):
+        try:
+            url = f"{base_url}/orchestrator/app/cd-pipeline/{app_id}"
+            response = requests.get(url, headers=headers)
+            if not response.status_code == 200:
+                return {
+                    "success": False,
+                    "error": "Failed to get CD Pipelines"
+                }
+            result = response.json().get("result", {})
+            return {
+                "success": True,
+                "cd_pipelines": result.get("pipelines", [])
+            }
+        except Exception as e:
+            return {
+                "success": False,
+                "error": f"Exception occurred: {str(e)}"
+            }
\ No newline at end of file
